@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-10-07'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.68'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -197,7 +197,6 @@ sub _list_config_params {
         my $ospec = $opts->{$_};
         next unless $ospec->{arg};
         next if $ospec->{main_opt};
-        next if grep {$_ eq 'hidden'} @{ $ospec->{arg_spec}{tags} // [] };
         next if $filter && !$filter->($ospec);
         my $oname = $ospec->{opt_parsed}{opts}[0];
         $oname = length($oname) > 1 ? "--$oname" : "-$oname";
@@ -527,7 +526,6 @@ sub _process_script {
                 push @content, "=head2 Common options\n\n";
                 push @content, "=over\n\n";
                 for (@opts) {
-                    next if 'hidden' ~~ @{ $opts->{$_}{tags} // [] };
                     push @content, _fmt_opt($_, $opts->{$_});
                 }
                 push @content, "=back\n\n";
@@ -558,7 +556,6 @@ sub _process_script {
                 push @content, "=head2 Options for subcommand $sc_name\n\n";
                 push @content, "=over\n\n";
                 for (@opts) {
-                    next if 'hidden' ~~ @{ $opts->{$_}{tags} // [] };
                     push @content, _fmt_opt($_, $opts->{$_});
                 }
                 push @content, "=back\n\n";
@@ -587,7 +584,6 @@ sub _process_script {
                 } @{ $options_by_cat{$cat} };
                 push @content, "=over\n\n";
                 for (@opts) {
-                    next if 'hidden' ~~ @{ $opts->{$_}{tags} // [] };
                     push @content, _fmt_opt($_, $opts->{$_});
                 }
                 push @content, "=back\n\n";
@@ -891,7 +887,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.67 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-10-07.
+This document describes version 0.68 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-10-27.
 
 =head1 SYNOPSIS
 
@@ -990,7 +986,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
 
 =head1 BUGS
 
